tuplettools.set_denominator_of_tuplets_in_expr_to_at_least
==========================================================

.. autofunction:: abjad.tools.tuplettools.set_denominator_of_tuplets_in_expr_to_at_least.set_denominator_of_tuplets_in_expr_to_at_least
